@@ -50,6 +50,44 @@ utils::globalVariables(
     "value_rescaled",
     "Meeting_hours_with_manager_1_1",
     "Meetings_with_manager_1_on_1",
-    "Cadence_of_1_on_1_meetings_with_manager"
+    "Cadence_of_1_on_1_meetings_with_manager",
+    "Organization",
+    "flag_nkw",
+    "holidayweek",
+    "mean_collab",
+    "perc",
+    "perc_nkw",
+    "total",
+    "ymax",
+    "ymin",
+    "z_score",
+    ".N",
+    "After_hours_collaboration_hours",
+    "Attributes",
+    "CH_ratio",
+    "Collaboration_hrs",
+    "HRAttribute",
+    "Unique values",
+    "WorkingEndTimeSetInOutlook",
+    "name",
+    "Email_hours",
+    "Instant_message_hours",
+    "values",
+    "WorkingStartTimeSetInOutlook",
+    "output_list",
+    "Email_ratio",
+    "PersonCount",
+    "WorkdayFlag",
+    "WorkdayRange",
+    "identifier",
+    "pre_group",
+    "Emails_sent",
+    "Shifts",
+    "WorkdayFlag1",
+    "subject_validate",
+    "FirstValue",
+    "TenureYear",
+    "WorkdayFlag2",
+    "tenure_years"
     )
 )
